@@ -6,9 +6,12 @@
  * @brief This header includes all commonly used effects for libopenshot, for ease-of-use.
  * @author Jonathan Thomas <jonathan@openshot.org>
  *
- * @section LICENSE
+ * @ref License
+ */
+
+/* LICENSE
  *
- * Copyright (c) 2008-2014 OpenShot Studios, LLC
+ * Copyright (c) 2008-2019 OpenShot Studios, LLC
  * <http://www.openshotstudios.com/>. This file is part of
  * OpenShot Library (libopenshot), an open-source project dedicated to
  * delivering high quality video editing and animation solutions to the
@@ -29,13 +32,20 @@
  */
 
 /* Effects */
+#include "effects/Bars.h"
 #include "effects/Blur.h"
 #include "effects/Brightness.h"
 #include "effects/ChromaKey.h"
+#include "effects/ColorShift.h"
+#include "effects/Crop.h"
 #include "effects/Deinterlace.h"
+#include "effects/Hue.h"
 #include "effects/Mask.h"
 #include "effects/Negate.h"
+#include "effects/Pixelate.h"
 #include "effects/Saturation.h"
+#include "effects/Shift.h"
+#include "effects/Wave.h"
 
 
 #endif
